@@ -114,5 +114,5 @@ y <- y[order(abs(y$cooc), decreasing = TRUE), ]
 head(y)
 
 ## ---- results='hide', echo=FALSE------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
-invisible(if(file.exists("spanish-gsd-ud-2.3-181115.udpipe")) file.remove(c("spanish-gsd-ud-2.3-181115.udpipe")))
+invisible(if(file.exists(ud_model$file)) file.remove(c(ud_model$file)))
 
